@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class LangTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit LangTest(QObject *parent = Q_NULLPTR);
+    explicit LangTest(QObject *parent = nullptr);
     ~LangTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
