@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2015-2016 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -85,8 +85,7 @@ Gender &Gender::operator=(const Gender &other)
 
 QString Gender::toString() const
 {
-    QString str;
-    str += QLatin1String("Gender {\n");
+    QString str = QLatin1String("Gender {\n");
     str += QStringLiteral("    gender: %1\n").arg(d->gender);
     str += QStringLiteral("    comment: %1\n").arg(d->comment);
     str += QLatin1String("}\n");
